# AIND Behavior Launcher Example With SLIMS

## Example Code

The following example shows how to instantiate a behavior launcher that interfaces with AIND infrastructure and uses SLIMS to fetch session data.

```python
--8<-- "examples/slims_launcher.py"
```